==> tccli-3.0.195.1-py2.py3-none-any.whl: tccli/services/nlp/v20190408/help.py <==
# -*- coding: utf-8 -*-
DESC = "nlp-2019-04-08"
INFO = {
  "WordSimilarity": {
    "params": [
      {
        "name": "SrcWord",
        "desc": "计算相似度的源词（仅支持UTF-8格式，不超过20字）"
      },
      {
        "name": "TargetWord",
        "desc": "计算相似度的目标词（仅支持UTF-8格式，不超过20字）"
      }
    ],
    "desc": "词相似度接口能够基于词向量技术来计算两个输入词语的余弦相似度，相似度数值越大的两个词语在语义上越相似。"
  },
  "DescribeEntity": {
    "params": [
      {
        "name": "EntityName",
        "desc": "实体名称"
      }
    ],
    "desc": "输入实体名称，返回实体相关的信息如实体别名、实体英文名、实体详细信息、相关实体等。"
  },
  "TextSimilarity": {
    "params": [
      {
        "name": "SrcText",
        "desc": "需要与目标句子计算相似度的源句子（仅支持UTF-8格式，不超过500字）"
      },
      {
        "name": "TargetText",
        "desc": "需要与源句子计算相似度的一个或多个目标句子（仅支持UTF-8格式，目标句子的数量不超过100个，每个句子不超过500字）\n注意：每成功计算1个目标句子与源句子的相似度算1次调用"
      }
    ],
    "desc": "句子相似度接口能够基于深度学习技术来计算一个源句子和多个目标句子的相似度，相似度分值越大的两个句子在语义上越相似。目前仅支持短文本的相似度计算，长文本的相似度计算也即将推出。\n\n鉴于句子相似度是一个应用非常广泛的功能，腾讯云自然语言处理团队在Bert等领先的深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于句子相似度，可以轻松实现诸如文本去重、相似推荐等功能。"
  },
  "SentenceSimilarity": {
    "params": [
      {
        "name": "SrcText",
        "desc": "计算相似度的源句子（仅支持UTF-8格式，不超过500字）"
      },
      {
        "name": "TargetText",
        "desc": "计算相似度的目标句子（仅支持UTF-8格式，不超过500字）"
      }
    ],
    "desc": "文本相似度接口能够基于深度学习技术来计算两个输入文本的相似度，相似度数值越大的两个文本在语义上越相似。目前仅支持短文本的相似度计算，长文本的相似度计算也即将推出。\n\n鉴于文本相似度是一个应用非常广泛的功能，腾讯知文自然语言处理团队在深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于文本相似度，可以轻松实现诸如文本去重、相似推荐等功能。"
  },
  "ChatBot": {
    "params": [
      {
        "name": "Query",
        "desc": "用户请求的query"
      },
      {
        "name": "Flag",
        "desc": "0: 通用闲聊, 1:儿童闲聊, 默认是通用闲聊"
      },
      {
        "name": "OpenId",
        "desc": "服务的id,  主要用于儿童闲聊接口，比如手Q的openid"
      }
    ],
    "desc": "闲聊服务基于腾讯领先的NLP引擎能力、数据运算能力和千亿级互联网语料数据的支持，同时集成了广泛的知识问答能力，可实现上百种自定义属性配置，以及儿童语言风格及说话方式，从而让聊天变得更睿智、简单和有趣。\n\n"
  },
  "LexicalAnalysis": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过500字）"
      },
      {
        "name": "DictId",
        "desc": "指定要加载的自定义词库ID。"
      },
      {
        "name": "Flag",
        "desc": "词法分析模式（默认取2值）：\n1、高精度（混合粒度分词能力）；\n2、高性能（单粒度分词能力）；"
      }
    ],
    "desc": "词法分析接口提供以下三个功能：\n\n1、智能分词：将连续的自然语言文本，切分成具有语义合理性和完整性的词汇序列；\n\n2、词性标注：为每一个词附上对应的词性，例如名词、代词、形容词、动词等；\n\n3、命名实体识别：快速识别文本中的实体，例如人名、地名、机构名等。\n\n所有的功能均基于千亿级大规模互联网语料进行持续迭代更新，以保证效果不断提升，用户无需担心新词发现、歧义消除、调用性能等问题。目前词法分析已经在泛互联网、金融、政务等不同垂直领域提供业务支持，并取得良好的效果。"
  },
  "DescribeRelation": {
    "params": [
      {
        "name": "LeftEntityName",
        "desc": "输入第一个实体"
      },
      {
        "name": "RightEntityName",
        "desc": "输入第二个实体"
      }
    ],
    "desc": "输入两个实体，返回两个实体间的关系，例如马化腾与腾讯公司不仅是相关实体，二者还存在隶属关系（马化腾属于腾讯公司）。"
  },
  "DependencyParsing": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过200字）"
      }
    ],
    "desc": "句法依存分析接口能够分析出句子中词与词之间的相互依存关系，并揭示其句法结构，包括主谓关系、动宾关系、核心关系等等，可用于提取句子主干、提取句子核心词等，在机器翻译、自动问答、知识抽取等领域都有很好的应用。"
  },
  "SentimentAnalysis": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过200字）"
      },
      {
        "name": "Flag",
        "desc": "待分析文本所属的类型，仅当输入参数Mode取值为2class时有效（默认取4值）：\n1、商品评论类\n2、社交类\n3、美食酒店类\n4、通用领域类"
      },
      {
        "name": "Mode",
        "desc": "情感分类模式选项，可取2class或3class（默认值为2class）\n1、2class：返回正负面二分类情感结果\n2、3class：返回正负面及中性三分类情感结果"
      }
    ],
    "desc": "情感分析接口能够对带有情感色彩的主观性文本进行分析、处理、归纳和推理，识别出用户的情感倾向，是积极还是消极，并且提供各自概率。\n\n该功能基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升。"
  },
  "WordEmbedding": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的词语（仅支持UTF-8格式，不超过20字）"
      }
    ],
    "desc": "词向量接口能够将输入的词语映射成一个固定维度的词向量，用来表示这个词语的语义特征。词向量是很多自然语言处理技术的基础，能够显著提高它们的效果。\n\n该词向量服务由腾讯知文自然语言处理团队联合腾讯AI Lab共同打造。使用的词向量基于千亿级大规模互联网语料并采用AI Lab自研的DSG算法训练而成，开源的词向量包含800多万中文词汇，在覆盖率、新鲜度及准确性等三方面性能突出。\n\n腾讯AI Lab词向量相关资料：\n\nhttps://ai.tencent.com/ailab/zh/news/detial?id=22\n\nhttps://ai.tencent.com/ailab/nlp/zh/embedding.html"
  },
  "TextCorrection": {
    "params": [
      {
        "name": "Text",
        "desc": "待纠错的文本（仅支持UTF-8格式，不超过2000字）"
      }
    ],
    "desc": "提供对中文文本的自动纠错功能，能够识别输入文本中的错误片段，定位错误并给出正确的文本结果；支持长度不超过2000字的长文本纠错。\n\n此功能是基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升，是搜索引擎、语音识别、内容审核等功能更好运行的基础之一。 "
  },
  "DescribeTriple": {
    "params": [
      {
        "name": "TripleCondition",
        "desc": "三元组查询条件"
      }
    ],
    "desc": "三元组查询，主要分为两类，SP查询和PO查询。SP查询表示已知主语和谓语查询宾语，PO查询表示已知宾语和谓语查询主语。每一个SP或PO查询都是一个可独立执行的查询，TQL支持SP查询的嵌套查询，即主语可以是一个嵌套的子查询。其他复杂的三元组查询方法，请参考官网API文档示例。"
  },
  "KeywordsExtraction": {
    "params": [
      {
        "name": "Text",
        "desc": "待处理的文本（仅支持UTF-8格式，不超过10000字）"
      },
      {
        "name": "Num",
        "desc": "指定关键词个数上限（默认值为5）"
      }
    ],
    "desc": "基于关键词提取平台，通过对文本内容进行深度分析，提取出文本内容中的关键信息，为用户实现诸如新闻内容关键词自动提取、评论关键词提取等提供基础服务。"
  },
  "SentenceEmbedding": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的文本（仅支持UTF-8格式，不超过500字）"
      }
    ],
    "desc": "句向量接口能够将输入的句子映射成一个固定维度的向量，用来表示这个句子的语义特征，可用于文本聚类、文本相似度、文本分类等任务，能够显著提高它们的效果。\n\n该句向量服务由腾讯云自然语言处理团队联合微信智言团队共同打造，基于千亿级大规模互联网语料并采用Bert等领先的深度神经网络模型训练而成，在腾讯内部诸多业务的NLP任务上实测效果显著。"
  },
  "AutoSummarization": {
    "params": [
      {
        "name": "Text",
        "desc": "待处理的文本（仅支持UTF-8格式，不超过2000字）"
      },
      {
        "name": "Length",
        "desc": "指定摘要的长度上限（默认值为200）\n注：为保证摘要的可读性，最终生成的摘要长度会低于指定的长度上限。"
      }
    ],
    "desc": "利用人工智能算法，自动抽取文本中的关键信息并生成指定长度的文本摘要。可用于新闻标题生成、科技文献摘要生成和商品评论摘要等。"
  },
  "SimilarWords": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的词语（仅支持UTF-8格式，不超过20字）"
      },
      {
        "name": "WordNumber",
        "desc": "相似词个数；取值范围：1-200，默认为10；"
      }
    ],
    "desc": "相似词接口能够基于同义词库及词向量技术，检索出与输入词语在语义上最相似的若干个词语，可广泛用于检索系统、问答系统、文档归档等场景。"
  },
  "TextClassification": {
    "params": [
      {
        "name": "Text",
        "desc": "待分类的文本（仅支持UTF-8格式，不超过10000字）"
      },
      {
        "name": "Flag",
        "desc": "领域分类体系（默认取1值）：\n1、通用领域\n2、新闻领域"
      }
    ],
    "desc": "文本分类接口能够对用户输入的文本进行自动分类，将其映射到具体的类目上，用户只需要提供待分类的文本，而无需关注具体实现。\n\n该功能基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升。\n\n目前已提供：\n\n- 通用领域分类体系，包括15个分类类目，分别是汽车、科技、健康、体育、旅行、教育、职业、文化、军事、房产、娱乐、女性、奥运、财经以及其他，适用于通用的场景。\n\n- 新闻领域分类体系，包括37个一级分类类目，285个二级分类（详细请见 [类目体系映射表](https://cloud.tencent.com/document/product/271/36459)），已应用于腾讯新闻的文章分类。\n\n更多垂直领域的分类体系即将推出，敬请期待。"
  }
}

==> tccli-3.0.210.1-py2.py3-none-any.whl: tccli/services/nlp/v20190408/help.py <==
# -*- coding: utf-8 -*-
DESC = "nlp-2019-04-08"
INFO = {
  "DescribeDict": {
    "params": [
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      },
      {
        "name": "Name",
        "desc": "自定义词库名称，模糊搜索。"
      }
    ],
    "desc": "根据id或名称查询自定义词库信息。"
  },
  "DescribeEntity": {
    "params": [
      {
        "name": "EntityName",
        "desc": "实体名称"
      }
    ],
    "desc": "输入实体名称，返回实体相关的信息如实体别名、实体英文名、实体详细信息、相关实体等。"
  },
  "SearchWordItems": {
    "params": [
      {
        "name": "WordItems",
        "desc": "待检索的词条集合。"
      },
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      }
    ],
    "desc": "查询指定自定义词库中的词条是否存在。"
  },
  "DeleteWordItems": {
    "params": [
      {
        "name": "WordItems",
        "desc": "待删除的词条集合。"
      },
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      }
    ],
    "desc": "用于删除自定义词库中的词条。"
  },
  "UpdateDict": {
    "params": [
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      },
      {
        "name": "Description",
        "desc": "词库描述，不超过100字。"
      },
      {
        "name": "Name",
        "desc": "词库名称，不超过20字。"
      }
    ],
    "desc": "修改自定义词库元数据信息，包括名称、描述。"
  },
  "DependencyParsing": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过200字）"
      }
    ],
    "desc": "句法依存分析接口能够分析出句子中词与词之间的相互依存关系，并揭示其句法结构，包括主谓关系、动宾关系、核心关系等等，可用于提取句子主干、提取句子核心词等，在机器翻译、自动问答、知识抽取等领域都有很好的应用。"
  },
  "WordEmbedding": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的词语（仅支持UTF-8格式，不超过20字）"
      }
    ],
    "desc": "词向量接口能够将输入的词语映射成一个固定维度的词向量，用来表示这个词语的语义特征。词向量是很多自然语言处理技术的基础，能够显著提高它们的效果。\n\n该词向量服务由腾讯知文自然语言处理团队联合腾讯AI Lab共同打造。使用的词向量基于千亿级大规模互联网语料并采用AI Lab自研的DSG算法训练而成，开源的词向量包含800多万中文词汇，在覆盖率、新鲜度及准确性等三方面性能突出。\n\n腾讯AI Lab词向量相关资料：\n\nhttps://ai.tencent.com/ailab/zh/news/detial?id=22\n\nhttps://ai.tencent.com/ailab/nlp/zh/embedding.html"
  },
  "DescribeDicts": {
    "params": [
      {
        "name": "Limit",
        "desc": "每页数据量，范围为1~100，默认为10。"
      },
      {
        "name": "Offset",
        "desc": "分页偏移量，从0开始，默认为0。"
      }
    ],
    "desc": "返回属于当前用户的所有自定义词库列表。"
  },
  "CreateDict": {
    "params": [
      {
        "name": "Name",
        "desc": "自定义词库名称，不超过20字。"
      },
      {
        "name": "Description",
        "desc": "自定义词库描述，不超过100字。"
      }
    ],
    "desc": "根据指定的名称、描述创建自定义词库。"
  },
  "SentenceEmbedding": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的文本（仅支持UTF-8格式，不超过500字）"
      }
    ],
    "desc": "句向量接口能够将输入的句子映射成一个固定维度的向量，用来表示这个句子的语义特征，可用于文本聚类、文本相似度、文本分类等任务，能够显著提高它们的效果。\n\n该句向量服务由腾讯云自然语言处理团队联合微信智言团队共同打造，基于千亿级大规模互联网语料并采用Bert等领先的深度神经网络模型训练而成，在腾讯内部诸多业务的NLP任务上实测效果显著。"
  },
  "TextClassification": {
    "params": [
      {
        "name": "Text",
        "desc": "待分类的文本（仅支持UTF-8格式，不超过10000字）"
      },
      {
        "name": "Flag",
        "desc": "领域分类体系（默认取1值）：\n1、通用领域\n2、新闻领域"
      }
    ],
    "desc": "文本分类接口能够对用户输入的文本进行自动分类，将其映射到具体的类目上，用户只需要提供待分类的文本，而无需关注具体实现。\n\n该功能基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升。\n\n目前已提供：\n\n- 通用领域分类体系，包括15个分类类目，分别是汽车、科技、健康、体育、旅行、教育、职业、文化、军事、房产、娱乐、女性、奥运、财经以及其他，适用于通用的场景。\n\n- 新闻领域分类体系，包括37个一级分类类目，285个二级分类（详细请见 [类目体系映射表](https://cloud.tencent.com/document/product/271/36459)），已应用于腾讯新闻的文章分类。\n\n更多垂直领域的分类体系即将推出，敬请期待。"
  },
  "WordSimilarity": {
    "params": [
      {
        "name": "SrcWord",
        "desc": "计算相似度的源词（仅支持UTF-8格式，不超过20字）"
      },
      {
        "name": "TargetWord",
        "desc": "计算相似度的目标词（仅支持UTF-8格式，不超过20字）"
      }
    ],
    "desc": "词相似度接口能够基于词向量技术来计算两个输入词语的余弦相似度，相似度数值越大的两个词语在语义上越相似。"
  },
  "SentenceSimilarity": {
    "params": [
      {
        "name": "SrcText",
        "desc": "计算相似度的源句子（仅支持UTF-8格式，不超过500字符）"
      },
      {
        "name": "TargetText",
        "desc": "计算相似度的目标句子（仅支持UTF-8格式，不超过500字符）"
      }
    ],
    "desc": "文本相似度接口能够基于深度学习技术来计算两个输入文本的相似度，相似度数值越大的两个文本在语义上越相似。目前仅支持短文本（不超过500字符）的相似度计算，长文本的相似度计算也即将推出。\n\n鉴于文本相似度是一个应用非常广泛的功能，腾讯知文自然语言处理团队在深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于文本相似度，可以轻松实现诸如文本去重、相似推荐等功能。"
  },
  "DescribeRelation": {
    "params": [
      {
        "name": "LeftEntityName",
        "desc": "输入第一个实体"
      },
      {
        "name": "RightEntityName",
        "desc": "输入第二个实体"
      }
    ],
    "desc": "输入两个实体，返回两个实体间的关系，例如马化腾与腾讯公司不仅是相关实体，二者还存在隶属关系（马化腾属于腾讯公司）。"
  },
  "DescribeWordItems": {
    "params": [
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      },
      {
        "name": "Limit",
        "desc": "每页数据量，范围为1~100，默认为10。"
      },
      {
        "name": "Offset",
        "desc": "分页偏移量，从0开始，默认为0。"
      },
      {
        "name": "Text",
        "desc": "待检索的词条文本，支持模糊匹配。"
      }
    ],
    "desc": "依据自定义词库的ID，查询对应的词条信息。"
  },
  "TextCorrection": {
    "params": [
      {
        "name": "Text",
        "desc": "待纠错的文本（仅支持UTF-8格式，不超过2000字）"
      }
    ],
    "desc": "提供对中文文本的自动纠错功能，能够识别输入文本中的错误片段，定位错误并给出正确的文本结果；支持长度不超过2000字的长文本纠错。\n\n此功能是基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升，是搜索引擎、语音识别、内容审核等功能更好运行的基础之一。 "
  },
  "CreateWordItems": {
    "params": [
      {
        "name": "WordItems",
        "desc": "待添加的词条集合。"
      },
      {
        "name": "DictId",
        "desc": "自定义词库ID。"
      }
    ],
    "desc": "向指定的词库中添加词条。"
  },
  "TextSimilarity": {
    "params": [
      {
        "name": "SrcText",
        "desc": "需要与目标句子计算相似度的源句子（仅支持UTF-8格式，不超过500字符）"
      },
      {
        "name": "TargetText",
        "desc": "需要与源句子计算相似度的一个或多个目标句子（仅支持UTF-8格式，目标句子的数量不超过100个，每个句子不超过500字符）\n注意：每成功计算1个目标句子与源句子的相似度算1次调用"
      }
    ],
    "desc": "句子相似度接口能够基于深度学习技术来计算一个源句子和多个目标句子的相似度，相似度分值越大的两个句子在语义上越相似。目前仅支持短文本（不超过500字符）的相似度计算，长文本的相似度计算也即将推出。\n\n鉴于句子相似度是一个应用非常广泛的功能，腾讯云自然语言处理团队在Bert等领先的深度神经网络模型的基础上，专门针对文本相似任务进行了优化，并持续迭代更新。基于句子相似度，可以轻松实现诸如文本去重、相似推荐等功能。"
  },
  "SentimentAnalysis": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过200字）"
      },
      {
        "name": "Flag",
        "desc": "待分析文本所属的类型，仅当输入参数Mode取值为2class时有效（默认取4值）：\n1、商品评论类\n2、社交类\n3、美食酒店类\n4、通用领域类"
      },
      {
        "name": "Mode",
        "desc": "情感分类模式选项，可取2class或3class（默认值为2class）\n1、2class：返回正负面二分类情感结果\n2、3class：返回正负面及中性三分类情感结果"
      }
    ],
    "desc": "情感分析接口能够对带有情感色彩的主观性文本进行分析、处理、归纳和推理，识别出用户的情感倾向，是积极还是消极，并且提供各自概率。\n\n该功能基于千亿级大规模互联网语料和LSTM、BERT等深度神经网络模型进行训练，并持续迭代更新，以保证效果不断提升。"
  },
  "ChatBot": {
    "params": [
      {
        "name": "Query",
        "desc": "用户请求的query"
      },
      {
        "name": "Flag",
        "desc": "0: 通用闲聊, 1:儿童闲聊, 默认是通用闲聊"
      },
      {
        "name": "OpenId",
        "desc": "服务的id,  主要用于儿童闲聊接口，比如手Q的openid"
      }
    ],
    "desc": "闲聊服务基于腾讯领先的NLP引擎能力、数据运算能力和千亿级互联网语料数据的支持，同时集成了广泛的知识问答能力，可实现上百种自定义属性配置，以及儿童语言风格及说话方式，从而让聊天变得更睿智、简单和有趣。\n\n"
  },
  "LexicalAnalysis": {
    "params": [
      {
        "name": "Text",
        "desc": "待分析的文本（仅支持UTF-8格式，不超过500字）"
      },
      {
        "name": "DictId",
        "desc": "指定要加载的自定义词库ID。"
      },
      {
        "name": "Flag",
        "desc": "词法分析模式（默认取2值）：\n1、高精度（混合粒度分词能力）；\n2、高性能（单粒度分词能力）；"
      }
    ],
    "desc": "词法分析接口提供以下三个功能：\n\n1、智能分词：将连续的自然语言文本，切分成具有语义合理性和完整性的词汇序列；\n\n2、词性标注：为每一个词附上对应的词性，例如名词、代词、形容词、动词等；\n\n3、命名实体识别：快速识别文本中的实体，例如人名、地名、机构名等。\n\n所有的功能均基于千亿级大规模互联网语料进行持续迭代更新，以保证效果不断提升，用户无需担心新词发现、歧义消除、调用性能等问题。目前词法分析已经在泛互联网、金融、政务等不同垂直领域提供业务支持，并取得良好的效果。"
  },
  "DescribeTriple": {
    "params": [
      {
        "name": "TripleCondition",
        "desc": "三元组查询条件"
      }
    ],
    "desc": "三元组查询，主要分为两类，SP查询和PO查询。SP查询表示已知主语和谓语查询宾语，PO查询表示已知宾语和谓语查询主语。每一个SP或PO查询都是一个可独立执行的查询，TQL支持SP查询的嵌套查询，即主语可以是一个嵌套的子查询。其他复杂的三元组查询方法，请参考官网API文档示例。"
  },
  "KeywordsExtraction": {
    "params": [
      {
        "name": "Text",
        "desc": "待处理的文本（仅支持UTF-8格式，不超过10000字）"
      },
      {
        "name": "Num",
        "desc": "指定关键词个数上限（默认值为5）"
      }
    ],
    "desc": "基于关键词提取平台，通过对文本内容进行深度分析，提取出文本内容中的关键信息，为用户实现诸如新闻内容关键词自动提取、评论关键词提取等提供基础服务。"
  },
  "DeleteDict": {
    "params": [
      {
        "name": "DictId",
        "desc": "要删除的自定义词库ID。"
      }
    ],
    "desc": "删除自定义词库，会附带相应删除词库包含的所有词条。"
  },
  "SimilarWords": {
    "params": [
      {
        "name": "Text",
        "desc": "输入的词语（仅支持UTF-8格式，不超过20字）"
      },
      {
        "name": "WordNumber",
        "desc": "相似词个数；取值范围：1-200，默认为10；"
      }
    ],
    "desc": "相似词接口能够基于同义词库及词向量技术，检索出与输入词语在语义上最相似的若干个词语，可广泛用于检索系统、问答系统、文档归档等场景。"
  },
  "AutoSummarization": {
    "params": [
      {
        "name": "Text",
        "desc": "待处理的文本（仅支持UTF-8格式，不超过2000字）"
      },
      {
        "name": "Length",
        "desc": "指定摘要的长度上限（默认值为200）\n注：为保证摘要的可读性，最终生成的摘要长度会低于指定的长度上限。"
      }
    ],
    "desc": "利用人工智能算法，自动抽取文本中的关键信息并生成指定长度的文本摘要。可用于新闻标题生成、科技文献摘要生成和商品评论摘要等。"
  }
}
